#include <LiquidCrystal_I2C.h> // Library for LCD
#include "DHT.h"

#define DHTPIN 2     // Digital pin connected to the DHT sensor
#define MICROPHONE A0
#define BUZZER 8
#define LED 9

LiquidCrystal_I2C lcd = LiquidCrystal_I2C(0x27, 16, 2);
DHT dht(DHTPIN, DHT11);

int micVal = 0;
bool alert = false;
unsigned long currentMillis, prevMillis = 1000;  

void setup() {
  Serial.begin(9600);

  pinMode(MICROPHONE, INPUT);
  pinMode(BUZZER, OUTPUT);
  pinMode(LED, OUTPUT);

  lcd.init();
  lcd.backlight();

  lcd.setCursor(4, 0); 
  lcd.print("Hello!");
  
  dht.begin();
}

void loop() {
  // Wait a few seconds between measurements.
  delay(1000);

  // Reading temperature or humidity takes about 250 milliseconds!
  // Sensor readings may also be up to 2 seconds 'old' (its a very slow sensor)
  float h = dht.readHumidity();
  // Read temperature as Celsius (the default)
  float t = dht.readTemperature();


  // Check if any reads failed and exit early (to try again).
  if (isnan(h) || isnan(t)) {
    Serial.println(F("Failed to read from DHT sensor!"));
    return;
  }

  if (!alert) {
    lcd.clear();
    lcd.setCursor(3, 0); 
    lcd.print("Liniste!");
    lcd.setCursor(0, 1);
    lcd.print("T:" + String(t) + "C " + "H:" + String(h));
    noTone(BUZZER);
    digitalWrite(LED, LOW);
    
    readMicrophone();
  } else {
    lcd.clear();
    lcd.setCursor(0, 0); 
    lcd.print("Alerta zgomot!");
    lcd.setCursor(0, 1);
    lcd.print("T:" + String(t) + "C " + "H:" + String(h));
  
    tone(BUZZER, 2000);
    digitalWrite(LED, HIGH);
    delay(4000);
    alert = false;
  }
}

void readMicrophone( ) {
  micVal = analogRead(MICROPHONE);
  unsigned long currentMillis = millis();
  Serial.println(micVal);

  if (micVal > 70 && (currentMillis  - prevMillis > 2000)) {
    Serial.println(String(currentMillis) + " " + String(prevMillis));
    prevMillis = currentMillis;
    alert = true;
    Serial.println("mic detected");
  }
}
